==> haskell-csv-0.1.2-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 csv
version:              0.1.2
visibility:           public
id:                   csv-0.1.2-LmEfVSswTyXHwaZ0ia2BWj
key:                  csv-0.1.2-LmEfVSswTyXHwaZ0ia2BWj
license:              MIT
copyright:            Jaap Weel, 2007
maintainer:           Jaap Weel <weel@ugcs.caltech.edu>
author:               Jaap Weel <weel@ugcs.caltech.edu>
synopsis:             CSV loader and dumper
description:
    CSV loader and dumper

    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.

category:             Text
abi:                  6f128c1cd2a99fb665dae54fbf0c94d2
exposed:              True
exposed-modules:      Text.CSV
import-dirs:          /usr/lib/ghc-9.0.2/site-local/csv-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/csv-0.1.2
hs-libraries:         HScsv-0.1.2-LmEfVSswTyXHwaZ0ia2BWj
depends:              base-4.15.1.0 filepath-1.4.2.1 parsec-3.1.14.0
haddock-interfaces:   /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html:         /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-csv-0.1.2-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 csv
version:              0.1.2
visibility:           public
id:                   csv-0.1.2-2mOrtFtvinGFo8c9ncR0hW
key:                  csv-0.1.2-2mOrtFtvinGFo8c9ncR0hW
license:              MIT
copyright:            Jaap Weel, 2007
maintainer:           Jaap Weel <weel@ugcs.caltech.edu>
author:               Jaap Weel <weel@ugcs.caltech.edu>
synopsis:             CSV loader and dumper
description:
    CSV loader and dumper

    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.

category:             Text
abi:                  bb2b092a3e30e1c4690822beb710e8bc
exposed:              True
exposed-modules:      Text.CSV
import-dirs:          /usr/lib/ghc-9.2.8/site-local/csv-0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-csv
hs-libraries:         HScsv-0.1.2-2mOrtFtvinGFo8c9ncR0hW
depends:              base-4.16.4.0 filepath-1.4.2.2 parsec-3.1.15.0
haddock-interfaces:   /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html:         /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
